@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2009,2010 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -32,7 +32,7 @@
 #include <cstdio>
 #include <cstring>
 
-gr_pfb_channelizer_ccf_sptr gr_make_pfb_channelizer_ccf (unsigned int numchans, 
+gr_pfb_channelizer_ccf_sptr gr_make_pfb_channelizer_ccf (unsigned int numchans,
 							 const std::vector<float> &taps,
 							 float oversample_rate)
 {
@@ -41,32 +41,34 @@ gr_pfb_channelizer_ccf_sptr gr_make_pfb_channelizer_ccf (unsigned int numchans,
 }
 
 
-gr_pfb_channelizer_ccf::gr_pfb_channelizer_ccf (unsigned int numchans, 
+gr_pfb_channelizer_ccf::gr_pfb_channelizer_ccf (unsigned int numchans,
 						const std::vector<float> &taps,
 						float oversample_rate)
   : gr_block ("pfb_channelizer_ccf",
 	      gr_make_io_signature (numchans, numchans, sizeof(gr_complex)),
-	      gr_make_io_signature (1, 1, numchans*sizeof(gr_complex))),
+	      gr_make_io_signature (1, numchans, sizeof(gr_complex))),
     d_updated (false), d_numchans(numchans), d_oversample_rate(oversample_rate)
 {
   // The over sampling rate must be rationally related to the number of channels
-  // in that it must be N/i for i in [1,N], which gives an outputsample rate 
+  // in that it must be N/i for i in [1,N], which gives an outputsample rate
   // of [fs/N, fs] where fs is the input sample rate.
   // This tests the specified input sample rate to see if it conforms to this
   // requirement within a few significant figures.
   double intp = 0;
   double fltp = modf(numchans / oversample_rate, &intp);
   if(fltp != 0.0)
-    throw std::invalid_argument("gr_pfb_channelizer: oversample rate must be N/i for i in [1, N]"); 
+    throw std::invalid_argument("gr_pfb_channelizer: oversample rate must be N/i for i in [1, N]");
 
   set_relative_rate(1.0/intp);
 
   d_filters = std::vector<gr_fir_ccf*>(d_numchans);
+  d_channel_map.resize(d_numchans);
 
   // Create an FIR filter for each channel and zero out the taps
   std::vector<float> vtaps(0, d_numchans);
   for(unsigned int i = 0; i < d_numchans; i++) {
     d_filters[i] = gr_fir_util::create_gr_fir_ccf(vtaps);
+    d_channel_map[i] = i;
   }
 
   // Now, actually set the filters' taps
@@ -94,8 +96,9 @@ gr_pfb_channelizer_ccf::gr_pfb_channelizer_ccf (unsigned int numchans,
 
 gr_pfb_channelizer_ccf::~gr_pfb_channelizer_ccf ()
 {
-  delete [] d_idxlut; 
-  
+  delete d_fft;
+  delete [] d_idxlut;
+
   for(unsigned int i = 0; i < d_numchans; i++) {
     delete d_filters[i];
   }
@@ -104,6 +107,7 @@ gr_pfb_channelizer_ccf::~gr_pfb_channelizer_ccf ()
 void
 gr_pfb_channelizer_ccf::set_taps (const std::vector<float> &taps)
 {
+  gruel::scoped_lock guard(d_mutex);
   unsigned int i,j;
 
   unsigned int ntaps = taps.size();
@@ -119,7 +123,7 @@ gr_pfb_channelizer_ccf::set_taps (const std::vector<float> &taps)
   while((float)(tmp_taps.size()) < d_numchans*d_taps_per_filter) {
     tmp_taps.push_back(0.0);
   }
- 
+
   // Partition the filter
   for(i = 0; i < d_numchans; i++) {
     // Each channel uses all d_taps_per_filter with 0's if not enough taps to fill out
@@ -127,7 +131,7 @@ gr_pfb_channelizer_ccf::set_taps (const std::vector<float> &taps)
     for(j = 0; j < d_taps_per_filter; j++) {
       d_taps[i][j] = tmp_taps[i + j*d_numchans];  // add taps to channels in reverse order
     }
-    
+
     // Build a filter for each channel and add it's taps to it
     d_filters[i]->set_taps(d_taps[i]);
   }
@@ -151,6 +155,33 @@ gr_pfb_channelizer_ccf::print_taps()
   }
 }
 
+std::vector< std::vector<float> >
+gr_pfb_channelizer_ccf::taps() const
+{
+  return d_taps;
+}
+
+void
+gr_pfb_channelizer_ccf::set_channel_map(const std::vector<int> &map)
+{
+  gruel::scoped_lock guard(d_mutex);
+
+  if(map.size() > 0) {
+    unsigned int max = (unsigned int)*std::max_element(map.begin(), map.end());
+    unsigned int min = (unsigned int)*std::min_element(map.begin(), map.end());
+    if((max >= d_numchans) || (min < 0)) {
+      throw std::invalid_argument("gr_pfb_channelizer_ccf::set_channel_map: map range out of bounds.\n");
+    }
+    d_channel_map = map;
+  }
+}
+
+std::vector<int>
+gr_pfb_channelizer_ccf::channel_map() const
+{
+  return d_channel_map;
+}
+
 
 int
 gr_pfb_channelizer_ccf::general_work (int noutput_items,
@@ -158,6 +189,8 @@ gr_pfb_channelizer_ccf::general_work (int noutput_items,
 				      gr_vector_const_void_star &input_items,
 				      gr_vector_void_star &output_items)
 {
+  gruel::scoped_lock guard(d_mutex);
+
   gr_complex *in = (gr_complex *) input_items[0];
   gr_complex *out = (gr_complex *) output_items[0];
 
@@ -166,7 +199,9 @@ gr_pfb_channelizer_ccf::general_work (int noutput_items,
     return 0;		     // history requirements may have changed.
   }
 
-  int n=1, i=-1, j=0, last;
+  size_t noutputs = output_items.size();
+
+  int n=1, i=-1, j=0, oo=0, last;
   int toconsume = (int)rintf(noutput_items/d_oversample_rate);
   while(n <= toconsume) {
     j = 0;
@@ -191,8 +226,13 @@ gr_pfb_channelizer_ccf::general_work (int noutput_items,
 
     // despin through FFT
     d_fft->execute();
-    memcpy(out, d_fft->get_outbuf(), d_numchans*sizeof(gr_complex));
-    out += d_numchans;
+
+    // Send to output channels
+    for(unsigned int nn = 0; nn < noutputs; nn++) {
+      out = (gr_complex*)output_items[nn];
+      out[oo] = d_fft->get_outbuf()[d_channel_map[nn]];
+    }
+    oo++;
   }
 
   consume_each(toconsume);
