@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2005,2010 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -38,14 +38,14 @@ gr_char_to_float::gr_char_to_float (size_t vlen, float scale)
   : gr_sync_block ("gr_char_to_float",
 		   gr_make_io_signature (1, 1, sizeof (char)*vlen),
 		   gr_make_io_signature (1, 1, sizeof (float)*vlen)),
-    d_vlen(vlen), d_scale(scale)    
+    d_vlen(vlen), d_scale(scale)
 {
   const int alignment_multiple =
     volk_get_alignment() / sizeof(float);
-  set_alignment(alignment_multiple);
+  set_alignment(std::max(1,alignment_multiple));
 }
 
-float 
+float
 gr_char_to_float::scale() const
 {
   return d_scale;
