@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2004,2010,2012 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -42,10 +42,10 @@ gr_float_to_char::gr_float_to_char (size_t vlen, float scale)
 {
   const int alignment_multiple =
     volk_get_alignment() / sizeof(char);
-  set_alignment(alignment_multiple);
+  set_alignment(std::max(1,alignment_multiple));
 }
 
-float 
+float
 gr_float_to_char::scale() const
 {
   return d_scale;
@@ -71,7 +71,7 @@ gr_float_to_char::work (int noutput_items,
   else {
     volk_32f_s32f_convert_8i_a(out, in, d_scale, d_vlen*noutput_items);
   }
-  
+
   return noutput_items;
 }
 
