@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2011,2012 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -43,10 +43,10 @@ gr_float_to_int::gr_float_to_int (size_t vlen, float scale)
 {
   const int alignment_multiple =
     volk_get_alignment() / sizeof(int);
-  set_alignment(alignment_multiple);
+  set_alignment(std::max(1,alignment_multiple));
 }
 
-float 
+float
 gr_float_to_int::scale() const
 {
   return d_scale;
@@ -84,6 +84,6 @@ gr_float_to_int::work (int noutput_items,
   gri_float_to_int (in, out, d_scale, d_vlen*noutput_items);
 
 #endif
-  
+
   return noutput_items;
 }
