@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2006,2008,2009,2011 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -85,7 +85,7 @@ protected:
     void set_input_signature(gr_io_signature_sptr iosig) {
         d_input_signature = iosig;
     }
-    
+
     //! may only be called during constructor
     void set_output_signature(gr_io_signature_sptr iosig) {
         d_output_signature = iosig;
@@ -103,7 +103,7 @@ public:
     std::string name() const { return d_name; }
     gr_io_signature_sptr input_signature() const  { return d_input_signature; }
     gr_io_signature_sptr output_signature() const { return d_output_signature; }
-    gr_basic_block_sptr to_basic_block(); // Needed for Python/Guile type coercion
+    gr_basic_block_sptr to_basic_block(); // Needed for Python type coercion
 
     /*!
      * \brief Confirm that ninputs and noutputs is an acceptable combination.
