@@ -1,35 +1,32 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2009 Free Software Foundation, Inc.
- * 
+ * Copyright 2011 Free Software Foundation, Inc.
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <qa_howto_square2_ff.h>
-#include <cppunit/TestAssert.h>
+#include <boost/test/unit_test.hpp>
 
-void
-qa_howto_square2_ff::t1()
-{
-  // Insert CPPUNIT tests/asserts here
+BOOST_AUTO_TEST_CASE(qa_howto_square2_ff_t1){
+    BOOST_CHECK_EQUAL(2 + 2, 4);
+    // TODO BOOST_* test macros here
 }
 
-void
-qa_howto_square2_ff::t2()
-{
-  // Insert CPPUNIT tests/asserts here
+BOOST_AUTO_TEST_CASE(qa_howto_square2_ff_t2){
+    BOOST_CHECK_EQUAL(2 + 2, 4);
+    // TODO BOOST_* test macros here
 }
